==> v3.0.tar.gz: privacyguides.org/docs/index.zh.md <==
---
template: overrides/home.en.html
hide:
  - 导航
  - toc
  - 反馈
---

<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## 我为什么要关心？

##### “我没有什么好藏的。 我为什么要关心自己的隐私？ ”

就像异族通婚的权利，女性的投票权，言论自由等等，我们的隐私权并不总是得到保护。 在几个独裁国家中，近乎完全不存在隐私。 我们之前的几代人为我们的隐私权而斗争。 ==隐私权是一项人权，是我们所有人固有的权利， == 我们应当不受歧视地享有。

您不应将隐私与保密混为一谈。 我们知道浴室里发生了什么，但你还是关上了门。 那是因为你想要隐私，而不是保密。 **每个人**都有需要保护的东西。 隐私是我们之所以为人的原因。

[:material-target-account: 常见互联网威胁] (basics/common-treats.md){ .md-button .md-button--primary }
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
我应该怎么办？

##### 首先，你需要指定一个计划

想一直保护你所有的数据不被任何人发现很不切实际，并且花费高昂且令人疲惫。 但是别担心！ 安全是一个过程，并且通过向前思考，你可以制定出一个适合你的计划。 安全并不仅仅是指你使用的工具或你下载的软件。 相反，它始于了解你所面临的独特的威胁，以及解决它们的办法。

==这种了解威胁和给出对策的过程称作**威胁建模**==，而它又构成了所有良好的安全和隐私计划的基础

[:material-book-outline: 了解有关威胁建模的更多信息](basics/threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding:3em;max-width:960px;margin:auto;text-align:center;" markdown>
## 我们需要你！ 以下是如何参与的方法：

对于像Privacy Guides这样的网站来说，始终保持更新是很重要的。 我们需要我们的用户关注我们网站上列出的应用程序的软件更新，并关注我们推荐的提供商的最新消息。 要跟上互联网的快节奏很难，但是我们会尽我们所能。 如果你发现了一处错误；或者觉得某个提供商不应被列出；或者注意到缺少了某个合格的提供商；或者认为某个浏览器插件不再是最好的选择；或者是发现了其他的问题，请告知我们。

<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:simple-discourse: 加入我们的论坛](https://discuss.privacyguides.net/)
- [:simple-mastodon: 在Mastodon上关注我们](https://mastodon.neat.computer/@privacyguides){ rel=me }
- [:material-book-edit: 对网站做贡献](https://github.com/privacyguides/privacyguides.org)
- [:simple-matrix: 在Matrix上跟我们交流](https://matrix.to/#/#privacyguides:matrix.org)
- [:material-information-outline: 关于我们](about/index.md)
- [:material-hand-coin-outline: 支持该项目](about/donate.md)

</div>
</div>

==> v3.2.tar.gz: privacyguides.org/docs/index.zh.md <==
---
template: overrides/home.en.html
hide:
  - navigation
  - toc
  - feedback
---

<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## 我为什么要关心？

##### “我没有什么好藏的。 我为什么要关心自己的隐私？ ”

就像异族通婚的权利，女性的投票权，言论自由等等，我们的隐私权并不总是得到保护。 在几个独裁国家中，近乎完全不存在隐私。 我们之前的几代人为我们的隐私权而斗争。 ==隐私权是一项人权，是我们所有人固有的权利， == 我们应当不受歧视地享有。

您不应将隐私与保密混为一谈。 我们知道浴室里发生了什么，但你还是关上了门。 那是因为你想要隐私，而不是保密。 **每个人**都有需要保护的东西。 隐私是我们之所以为人的原因。

[:material-target-account: 常见互联网威胁](basics/common-treats.md){ .md-button .md-button--primary }
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
我应该怎么办？

##### 首先，你需要指定一个计划

想一直保护你所有的数据不被任何人发现很不切实际，并且花费高昂且令人疲惫。 但是别担心！ 安全是一个过程，并且通过向前思考，你可以制定出一个适合你的计划。 安全并不仅仅是指你使用的工具或你下载的软件。 相反，它始于了解你所面临的独特的威胁，以及解决它们的办法。

==这种了解威胁和给出对策的过程称作**威胁模型分析**==，而它又构成了所有良好的安全和隐私计划的基础

[:material-book-outline: 了解有关威胁模型分析的更多信息](basics/threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding:3em;max-width:960px;margin:auto;text-align:center;" markdown>
## 我们需要你！ 以下是如何参与的方法：

对于像Privacy Guides这样的网站来说，始终保持更新是很重要的。 我们需要我们的用户关注我们网站上列出的应用程序的软件更新，并关注我们推荐的提供商的最新消息。 要跟上互联网的快节奏很难，但是我们会尽我们所能。 如果你发现了一处错误；或者觉得某个提供商不应被列出；或者注意到缺少了某个合格的提供商；或者认为某个浏览器插件不再是最好的选择；或者是发现了其他的问题，请告知我们。

<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:simple-discourse: 加入我们的论坛](https://discuss.privacyguides.net/)
- [:simple-mastodon: 在Mastodon上关注我们](https://mastodon.neat.computer/@privacyguides){ rel=me }
- [:material-book-edit: 对网站做贡献](https://github.com/privacyguides/privacyguides.org)
- [:simple-matrix: 在Matrix上跟我们交流](https://matrix.to/#/#privacyguides:matrix.org)
- [:material-information-outline: 关于我们](about/index.md)
- [:material-hand-coin-outline: 支持该项目](about/donate.md)

</div>
</div>
